<?php

namespace Drupal\price_spider\Form;

use Drupal\node\Entity\NodeType;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Building price spider config form.
 */
class PriceSpiderConfigureForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'pricespider_configure_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getEditableConfigNames() {
    return ['price_spider.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('price_spider.settings');
    $form['generic'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Generic Settings'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
      '#prefix' => '<div id="generic-pricespider">',
      '#suffix' => '</div>',
    ];
    $form['generic']['price_spider_key'] = [
      '#type' => 'textfield',
      '#size' => 40,
      '#required' => TRUE,
      '#title' => $this->t('Price Spider Key'),
      '#description' => $this->t('Enter price spider key.'),
      '#default_value' => $config->get('price_spider_key'),
    ];
    $form['generic']['price_spider_country'] = [
      '#type' => 'textfield',
      '#size' => 40,
      '#required' => TRUE,
      '#title' => $this->t('Price Spider Country'),
      '#description' => $this->t('Enter price spider country.'),
      '#default_value' => $config->get('price_spider_country'),
    ];
    $form['generic']['price_spider_language'] = [
      '#type' => 'textfield',
      '#size' => 40,
      '#required' => TRUE,
      '#title' => $this->t('Price Spider Language'),
      '#description' => $this->t('Enter price spider language.'),
      '#default_value' => $config->get('price_spider_language'),
    ];
    $form['generic']['price_spider_default_sku'] = [
      '#type' => 'textfield',
      '#size' => 40,
      '#required' => TRUE,
      '#title' => $this->t('Price Spider Default SKU'),
      '#description' => $this->t('Enter default sku of products, this would appear if no product specific sku added.'),
      '#default_value' => $config->get('price_spider_default_sku'),
    ];
    $form['pages'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Pages'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
      '#prefix' => '<div id="generic-pages">',
      '#suffix' => '</div>',
    ];
    $form['pages']['price_spider_pages'] = [
      '#type' => 'textarea',
      '#rows' => 5,
      '#cols' => 3,
      '#required' => FALSE,
      '#title' => $this->t('Pages List'),
      '#description' => $this->t('Enter pages where you want to page-spider script to appear. Enter each page in a new line.'),
      '#default_value' => $config->get('price_spider_pages'),
    ];
    $form['pages']['price_spider_exclude_pages'] = [
      '#type' => 'textarea',
      '#rows' => 5,
      '#cols' => 3,
      '#required' => FALSE,
      '#title' => $this->t('Exclude Pages List'),
      '#description' => $this->t('Enter pages where you do not want page-spider script to appear. Enter each page in a new line.'),
      '#default_value' => $config->get('price_spider_exclude_pages'),
    ];
    $form['content_types'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Content types'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
      '#prefix' => '<div id="generic-ctypes">',
      '#suffix' => '</div>',
    ];
    $node_types = NodeType::loadMultiple();
    $options = [];
    foreach ($node_types as $node_type) {
      $options[$node_type->id()] = $node_type->label();
    }
    $form['content_types']['price_spider_ctypes'] = [
      '#type' => 'checkboxes',
      '#required' => FALSE,
      '#title' => $this->t('Select Content Types'),
      '#options' => $options,
      '#default_value' => $config->get('price_spider_ctypes'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('price_spider.settings')
      ->set('price_spider_key', $form_state->getValue('price_spider_key'))
      ->set('price_spider_country', $form_state->getValue('price_spider_country'))
      ->set('price_spider_language', $form_state->getValue('price_spider_language'))
      ->set('price_spider_default_sku', $form_state->getValue('price_spider_default_sku'))
      ->set('price_spider_pages', $form_state->getValue('price_spider_pages'))
      ->set('price_spider_exclude_pages', $form_state->getValue('price_spider_exclude_pages'))
      ->set('price_spider_ctypes', $form_state->getValue('price_spider_ctypes'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
